<?php
namespace Teknisa\CADFIS\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Controller\CRUD;
use Teknisa\Libs\Util\DateUtil;
use Zeedhi\Framework\HTTP\Kernel;

class Ger00210DesativacaoDaEmissaoAutomaticaController extends \Teknisa\CADFIS\Controllers\TeknisaCrud {

    protected $entityManager;
    protected $environment;
    protected $dataSourceManager;
    protected $Ger00210DesativacaoDaEmissaoAutomaticaService;
    
    public function __construct($crudService, $parameterBag, $environment, $entityManager, $dataSourceManager, $Ger00210DesativacaoDaEmissaoAutomaticaService, Kernel $httpKernel) {
        parent::__construct($crudService, $parameterBag);
        $this->environment       = $environment;
        $this->entityManager     = $entityManager;
        $this->dataSourceManager = $dataSourceManager;
        $this->Service           = $Ger00210DesativacaoDaEmissaoAutomaticaService;
        $this->httpKernel        = $httpKernel;
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            $dataSourceName = 'desemiautonfce';
            
            $rows = $this->crudService->getRowsToSave($request, $dataSourceName);
            
            // Remove Máscara de CPF
            $cpf = preg_replace("/[^0-9]/", "", $row['NRINSJURSIG']);
            
            if($row['__is_new']){
                $email = $rows[0]['DSEMAIL'];
                
                $this->Service->getDesemiautonfceCpfOrEmail($cpf, $email);
                
                $nrorg      = $this->Service->GetNrorg();
                $sequential = $this->Service->GenereteSequential($row);
                
                $rows[0]['NRORG']           = $nrorg;
                $rows[0]['NRSEQDESEMIAUTO'] = $sequential;
                $rows[0]['NRINSJURSIG']     = $cpf;
            }else{
                $rows[0]['NRINSJURSIG']     = $cpf;
            }
            
            $this->crudService->save($dataSourceName, $rows);
        }catch(\Exception $e) { 
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function sign(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            // Base Url
            $baseurl   = $row['BASEURL'];
            
            // Empresa
            $cdempresa = $row['CDEMPRESA'];
            
            // Nome do Arquivo
            $nmDocumento = 'Termo de responsabilidade NFC-e.pdf';
            
            // Caminho do Arquivo
            $documento   = __DIR__.'/../../../../../mobile/assets/json/documentos/Termo de responsabilidade NFC-e.pdf';
            
            // Upload do Arquivo - Via Api CertSing
            $result = $this->Service->uploadToCertsing($nmDocumento, $documento);
            
            // Validação caso não consiga "Uplodar" o Arquivo
            if(!isset($result['response']['uploadId']))
                throw new \Exception('Erro na comunicação com a CertSign. <br/><br/>Status:<br/>'.$result['response']['statusCode']. '<br/><br/>Message:<br/>'.$result['response']['message']);
                        
            // Upload Id para identificação do Arquivo
            $uploadId = $result['response']['uploadId'];
            
            // Criação Assinaturas e Envio de E-mail Automático - Via Api Certsing
            $create = $this->Service->createSignatureCertsing($uploadId, $nmDocumento);
            
            // Validação caso não ache o Identificador
            if(!isset($create['response']['id']))
                throw new \Exception('Erro na comunicação com a CertSign. <br/><br/>Status:<br/>'.$create['response']['code']. '<br/><br/>Message:<br/>'.$create['response']['message']);
            
            // Identificador do Arquivo a Assinar
            $iddocassinat = $create['response']['id'];
            
            // Insere Identificador do Arquivo a ser Assinado na Centraliza
            $this->Service->insertCentralizaAssinatura($iddocassinat, $cdempresa, $baseurl);
            
            $response->addDataSet(new DataSet("RESULT", $create));
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function callbackCertsing(DTO\Request $request, DTO\Response $response){
        try {
            $parametros = $request->getParameters();
            $nrorg = $this->httpKernel->getHttpRequest()->getHeaders()->get("nrorg");
            
            $this->Service->callbackCertsing($parametros, $nrorg);
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}