<?php
namespace Teknisa\CADFIS\Factories;

use Doctrine\ORM\EntityManager;

class Ger00210DesativacaoDaEmissaoAutomaticaFactory {
    
    protected $connection;
    private $entityManager;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection    = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    public function getInscrEstad($cdinscesta, $cdempresa, $nrorg) {
        $sql = 'SELECT CDINSCESTA,
                       CDEMPRESA,
                       NRORG,
                       DSDIRCERTIFICADO
                  FROM INSCRESTAD
                 WHERE CDINSCESTA = :P_CDINSCESTA
                   AND CDEMPRESA  = :P_CDEMPRESA
                   AND NRORG      = :P_NRORG';
        
        $params = array(
            'P_CDINSCESTA' => $cdinscesta,
            'P_CDEMPRESA'  => $cdempresa,
            'P_NRORG'      => $nrorg
        );

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        
        return $query->fetchAll();
    }
    
    public function getParamCentrAssinatura (array $params) {
        $sql = "SELECT DSTOKENCERTSIGN, NMSENDERCERTSIGN, DSEMAILSENDERCERTSIGN, 
                       NRCPFSENDERCERTSIGN, IDPADRAOASSINACERTSIGN, NRTIPODOCCERTSIGN
                  FROM PARAM_CENTR_ASSINATURA
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetch();
    }
    
    public function getDesEmiAutoNfce (array $params) {
        $sql = "SELECT NRSEQDESEMIAUTO, NMSIGNATARIO, NRINSJURSIG, DSEMAIL, DSEMAILCOPIA
                  FROM DESEMIAUTONFCE
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }    
    
    public function getDesEmiAutoNfceCpfOrEmail (array $params) {
        $sql = "SELECT NRSEQDESEMIAUTO, NMSIGNATARIO, NRINSJURSIG, DSEMAIL, DSEMAILCOPIA
                  FROM DESEMIAUTONFCE
                 WHERE NRORG = :NRORG
                   AND ((NRINSJURSIG = :NRINSJURSIG) OR (DSEMAIL = :DSEMAIL))";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }    
    
    public function getRotasCentrAssinatura (array $params) {
        $sql = "SELECT ID
                  FROM ROTAS_CENTR_ASSINATURA 
                 WHERE NRORG          = :NRORG
                   AND DSCHAVEASSINAT = :DSCHAVEASSINAT";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetch();
    }
    
    public function insertRotasCentrAssinatura (array $params) {
        $sql = "INSERT INTO ROTAS_CENTR_ASSINATURA (
                    ID, DSCHAVEASSINAT, DSROTAASSINAT, NRORG, DSURLBASE, CLIENT_ID, CLIENT_SECRET, CDOPERINCLUSAO, CDOPERULTATU, NRORGINCLUSAO, NRORGULTATU, DTINCLUSAO, DTULTATU
                )VALUES(
                    :ID, :DSCHAVEASSINAT, :DSROTAASSINAT, :NRORG, :DSURLBASE, :CLIENT_ID, :CLIENT_SECRET, :CDOPERINCLUSAO, :CDOPERULTATU, :NRORGINCLUSAO, :NRORGULTATU, SYSDATE, SYSDATE
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function insertCentralizaAssinatura (array $params) {
        $sql = "INSERT INTO CENTRALIZA_ASSINATURA (
                    ID, DSCHAVEASSINAT, IDDOCASSINAT, NRORG, CDEMPRESA, CDOPERINCLUSAO, CDOPERULTATU, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, NRORGULTATU
                )VALUES(
                    :ID, :DSCHAVEASSINAT, :IDDOCASSINAT, :NRORG, :CDEMPRESA, :CDOPERINCLUSAO, :CDOPERULTATU, SYSDATE, SYSDATE, :NRORGINCLUSAO, :NRORGULTATU
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getCentralizaAssinatura (array $params) {
        $sql = "SELECT ID, CDEMPRESA, IDSTATASSINAT
                  FROM CENTRALIZA_ASSINATURA 
                 WHERE NRORG          = :NRORG
                   AND IDDOCASSINAT   = :IDDOCASSINAT
                   AND DSCHAVEASSINAT = :DSCHAVEASSINAT";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetch();
    }
    
    public function updateCentralizaAssinatura (array $params) {
        $sql = "UPDATE CENTRALIZA_ASSINATURA
                   SET IDSTATASSINAT = :IDSTATASSINAT
                 WHERE NRORG = :NRORG
                   AND ID    = :ID";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateEmpresa (array $params) {
        $sql = "UPDATE EMPRESA
                   SET IDIMPCUPMEI = :IDIMPCUPMEI
                 WHERE NRORG     = :NRORG
                   AND CDEMPRESA = :CDEMPRESA";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function insertLogCentrAssinatura (array $params) {
        $sql = "INSERT INTO LOG_CENTR_ASSINATURA (
                    ID, ID_CENTR_ASSINA, IDDOCASSINAT, NRCPFSIGNATARIO, IDACEITARECUSA, DSLOG, NRORG, DTINCLUSAO, DTULTATU, NRORGULTATU, NRORGINCLUSAO
                )VALUES(
                    :ID, :ID_CENTR_ASSINA, :IDDOCASSINAT, :NRCPFSIGNATARIO, :IDACEITARECUSA, :DSLOG, :NRORG, SYSDATE, SYSDATE, :NRORG, :NRORG
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}