/* Tabela TIPOCONSFILI: TABELA TIPO DE CONSUMIDOR POR FILIAL*/
/* Descrio: A trigger insere registros na tabela LOGOPERAVND a partir de alteraes na tabela TIPOCONSFILI */
/* Objetivo: Gerar um log que vai registrar as alteraes na TIPOCONSFILI,
             utilizando a tabela de Logs de Operaes do VND*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_VND_TIPOCONSFILI' AND
                 TYPE   = 'TR' 	               AND
	              U.UID  = O.UID           AND
	              U.NAME = USER)
DROP TRIGGER LOG_VND_TIPOCONSFILI
GO

CREATE TRIGGER LOG_VND_TIPOCONSFILI
ON TIPOCONSFILI
FOR INSERT, UPDATE, DELETE
AS
  DECLARE @V_DSREMOTEADDR VARCHAR(15);
  DECLARE @V_DSREMOTEHOST VARCHAR(15);
  DECLARE @V_DSSERVERRDM  VARCHAR(20);
  DECLARE @V_DSSERVMETHOD VARCHAR(30);
  DECLARE @V_DSREMOTEOPER VARCHAR(12);
  DECLARE @V_DESC         VARCHAR(500);
  DECLARE @V_ITPESQ       VARCHAR(40);
  DECLARE @V_NMOPERADOR   VARCHAR(40);
  DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE @V_ID_COMANDO    VARCHAR(1);
  
  DECLARE @V_NEW_CDFILIAL            varchar(4);
  DECLARE @V_NEW_CDTIPOCONS          varchar(2);
  DECLARE @V_NEW_DSACESSOSITE        varchar(20);

  DECLARE @V_OLD_CDFILIAL            varchar(4);
  DECLARE @V_OLD_CDTIPOCONS          varchar(2);
  DECLARE @V_OLD_DSACESSOSITE        varchar(20);

BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC   = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO @P_NMUSUARIO = @V_NMOPERADOR OUTPUT;
   SET @V_NMOPERADOR = ISNULL(@V_NMOPERADOR, ' ');

   EXEC WEBTUNNING  @P_DSREMOTEADDR = @V_DSREMOTEADDR OUTPUT,
                    @P_DSREMOTEHOST = @V_DSREMOTEHOST OUTPUT,
                    @P_DSSERVERRDM  = @V_DSSERVERRDM OUTPUT,
                    @P_DSSERVMETHOD = @V_DSSERVMETHOD OUTPUT,
                    @P_DSREMOTEOPER = @V_DSREMOTEOPER OUTPUT;

   DECLARE C_CURSOR CURSOR FOR
     SELECT
     'D'   ID_COMANDO,
           NULL,NULL,NULL,
           CDFILIAL,
           CDTIPOCONS,
           DSACESSOSITE


     FROM
           DELETED
     WHERE     
           CDFILIAL + CDTIPOCONS NOT IN (SELECT CDFILIAL + CDTIPOCONS FROM INSERTED)
     UNION ALL

     SELECT
     'U'   IDCOMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDTIPOCONS,
           INSERTED.DSACESSOSITE,
           DELETED.CDFILIAL,
           DELETED.CDTIPOCONS,
           DELETED.DSACESSOSITE
     FROM
           INSERTED,
           DELETED
     WHERE     
           INSERTED.CDFILIAL   = DELETED.CDFILIAL    AND
	   INSERTED.CDTIPOCONS = DELETED.CDTIPOCONS  
     UNION ALL

     SELECT
     'I'   IDCOMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDTIPOCONS,
           INSERTED.DSACESSOSITE,
	   NULL,NULL,NULL
     FROM
           INSERTED
     WHERE     
          CDFILIAL + CDTIPOCONS NOT IN (SELECT CDFILIAL + CDTIPOCONS FROM DELETED)


     OPEN C_CURSOR;
     FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                   @V_NEW_CDFILIAL,@V_NEW_CDTIPOCONS,@V_NEW_DSACESSOSITE,
                                   @V_OLD_CDFILIAL,@V_OLD_CDTIPOCONS,@V_OLD_DSACESSOSITE

    WHILE (@@FETCH_STATUS = 0) BEGIN
    
       IF @V_ID_COMANDO= 'U' /*UPDATE*/ BEGIN
		IF ISNULL(@V_NEW_CDFILIAL,'NULL') <> ISNULL(@V_OLD_CDFILIAL,'NULL') BEGIN
			SET @V_DESC   = 'Filial ' + ISNULL(@V_NEW_CDFILIAL,'');
		END;
		IF ISNULL(@V_NEW_CDTIPOCONS,'NULL') <> ISNULL(@V_OLD_CDTIPOCONS,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Tipo Consumidor  ' + ISNULL(@V_NEW_CDTIPOCONS,'');
		END;
		IF ISNULL(@V_NEW_DSACESSOSITE,'NULL') <> ISNULL(@V_OLD_DSACESSOSITE,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Permisso de Acesso ' + ISNULL(@V_NEW_DSACESSOSITE,'');
		END;
          SET @V_IDTIPOOPER = '2';
       END;
       IF @V_ID_COMANDO= 'I' /*INSERO*/ BEGIN
          SET @V_DESC   = 'Filial '               + ISNULL(@V_NEW_CDFILIAL,''    )  + ' ' +
                      'Tipo Consumidor  '     + ISNULL(@V_NEW_CDTIPOCONS,''  )  + ' ' +
                      'Permisso de Acesso '  + ISNULL(@V_NEW_DSACESSOSITE,'');
          SET @V_IDTIPOOPER = '1';
       END;
       IF @V_ID_COMANDO= 'D' /*DELEO*/  BEGIN
          SET @V_DESC   = 'Filial '               + ISNULL(@V_OLD_CDFILIAL,''    )  + ' ' +
                      'Tipo Consumidor  '     + ISNULL(@V_OLD_CDTIPOCONS,''  )  + ' ' +
                      'Permisso de Acesso '  + ISNULL(@V_OLD_DSACESSOSITE,'');
          SET @V_IDTIPOOPER = '3';
       END;
       IF  (@V_IDTIPOOPER <> '') BEGIN
          IF @V_DESC IS NOT NULL BEGIN
             SET @V_ITPESQ =  ISNULL(@V_NEW_CDFILIAL + @V_NEW_CDTIPOCONS ,@V_OLD_CDFILIAL + @V_OLD_CDTIPOCONS );
             SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);
             INSERT INTO LOGOPERAVND
                    (NMTABELAVND, DTOPERACAOVND, NMRESPOPERVND, IDTIPOOPERVND, DSOPERACAOVND,
                     CDPESQITEMVND, DSRDMUSUOPERVND, DSENDUSUOPERVND, DSNMUSUOPERVND, DSMETUSUOPERVND,
                     CDORESPOPERVND, CDFILLOGOPERVND)
             VALUES ('TIPOCONSFILI',GETDATE(), ISNULL(@V_NMOPERADOR,' '), @V_IDTIPOOPER, @V_DESC, @V_ITPESQ,
                     @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER,
                     ISNULL(@V_NEW_CDFILIAL,@V_OLD_CDFILIAL));
          END;
       END;
       FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                     @V_NEW_CDFILIAL,@V_NEW_CDTIPOCONS,@V_NEW_DSACESSOSITE,
                                     @V_OLD_CDFILIAL,@V_OLD_CDTIPOCONS,@V_OLD_DSACESSOSITE

    SET @V_DESC   = '';
    END;
    CLOSE      C_CURSOR;
    DEALLOCATE C_CURSOR;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_VND_TIPOCONSFILI','5.20.001';
GO 